"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.24.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from delphix.api.gateway.api_client import ApiClient, Endpoint as _Endpoint
from delphix.api.gateway.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from delphix.api.gateway.model.account_login_parameter import AccountLoginParameter
from delphix.api.gateway.model.error_response import ErrorResponse
from delphix.api.gateway.model.login_token import LoginToken
from delphix.api.gateway.model.token_info_request import TokenInfoRequest
from delphix.api.gateway.model.token_info_response import TokenInfoResponse


class LoginApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

        def __account_login(
            self,
            account_login_parameter,
            **kwargs
        ):
            """Login to Account with Username and Password   # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.account_login(account_login_parameter, async_req=True)
            >>> result = thread.get()

            Args:
                account_login_parameter (AccountLoginParameter):

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                LoginToken
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['account_login_parameter'] = \
                account_login_parameter
            return self.call_with_http_info(**kwargs)

        self.account_login = _Endpoint(
            settings={
                'response_type': (LoginToken,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/login',
                'operation_id': 'account_login',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'account_login_parameter',
                ],
                'required': [
                    'account_login_parameter',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'account_login_parameter':
                        (AccountLoginParameter,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'account_login_parameter': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__account_login
        )

        def __account_logout(
            self,
            authorization,
            **kwargs
        ):
            """Invalidates username/password and SSO login session.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.account_logout(authorization, async_req=True)
            >>> result = thread.get()

            Args:
                authorization (str): Access token

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                None
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['authorization'] = \
                authorization
            return self.call_with_http_info(**kwargs)

        self.account_logout = _Endpoint(
            settings={
                'response_type': None,
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/logout',
                'operation_id': 'account_logout',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'authorization',
                ],
                'required': [
                    'authorization',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'authorization':
                        (str,),
                },
                'attribute_map': {
                    'authorization': 'Authorization',
                },
                'location_map': {
                    'authorization': 'header',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [],
                'content_type': [],
            },
            api_client=api_client,
            callable=__account_logout
        )

        def __token_info(
            self,
            **kwargs
        ):
            """Get Token Information   # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.token_info(async_req=True)
            >>> result = thread.get()


            Keyword Args:
                token_info_request (TokenInfoRequest): [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                TokenInfoResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            return self.call_with_http_info(**kwargs)

        self.token_info = _Endpoint(
            settings={
                'response_type': (TokenInfoResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/token-info',
                'operation_id': 'token_info',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'token_info_request',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'token_info_request':
                        (TokenInfoRequest,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'token_info_request': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__token_info
        )



"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.24.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from delphix.api.gateway.model_utils import (  # noqa: F401
    ApiTypeError,
    ModelComposed,
    ModelNormal,
    ModelSimple,
    cached_property,
    change_keys_js_to_python,
    convert_js_args_to_python_args,
    date,
    datetime,
    file_type,
    none_type,
    validate_get_composed_info,
)
from ..model_utils import OpenApiModel
from delphix.api.gateway.exceptions import ApiAttributeError


def lazy_import():
    from delphix.api.gateway.model.target_job_type import TargetJobType
    from delphix.api.gateway.model.target_object_type import TargetObjectType
    from delphix.api.gateway.model.virtualization_job_event import VirtualizationJobEvent
    globals()['TargetJobType'] = TargetJobType
    globals()['TargetObjectType'] = TargetObjectType
    globals()['VirtualizationJobEvent'] = VirtualizationJobEvent


class VirtualizationJob(ModelNormal):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    Attributes:
      allowed_values (dict): The key is the tuple path to the attribute
          and the for var_name this is (var_name,). The value is a dict
          with a capitalized key describing the allowed value and an allowed
          value. These dicts store the allowed enum values.
      attribute_map (dict): The key is attribute name
          and the value is json key in definition.
      discriminator_value_class_map (dict): A dict to go from the discriminator
          variable value to the discriminator class name.
      validations (dict): The key is the tuple path to the attribute
          and the for var_name this is (var_name,). The value is a dict
          that stores validations for max_length, min_length, max_items,
          min_items, exclusive_maximum, inclusive_maximum, exclusive_minimum,
          inclusive_minimum, and regex.
      additional_properties_type (tuple): A tuple of classes accepted
          as additional properties values.
    """

    allowed_values = {
        ('job_state',): {
            'RUNNING': "RUNNING",
            'COMPLETED': "COMPLETED",
            'SUSPENDED': "SUSPENDED",
            'CANCELED': "CANCELED",
            'FAILED': "FAILED",
        },
    }

    validations = {
    }

    @cached_property
    def additional_properties_type():
        """
        This must be a method because a model may have properties that are
        of type self, this must run after the class is loaded
        """
        lazy_import()
        return (bool, date, datetime, dict, float, int, list, str, none_type,)  # noqa: E501

    _nullable = False

    @cached_property
    def openapi_types():
        """
        This must be a method because a model may have properties that are
        of type self, this must run after the class is loaded

        Returns
            openapi_types (dict): The key is attribute name
                and the value is attribute type.
        """
        lazy_import()
        return {
            'engine_job_id': (str,),  # noqa: E501
            'engine_id': (str,),  # noqa: E501
            'legacy_job_type': (str,),  # noqa: E501
            'job_type': (TargetJobType,),  # noqa: E501
            'target_object_id': (str,),  # noqa: E501
            'legacy_target_object_type': (str,),  # noqa: E501
            'target_object_type': (TargetObjectType,),  # noqa: E501
            'job_state': (str,),  # noqa: E501
            'start_time': (datetime,),  # noqa: E501
            'update_time': (datetime,),  # noqa: E501
            'suspendable': (bool,),  # noqa: E501
            'cancelable': (bool,),  # noqa: E501
            'queued': (bool,),  # noqa: E501
            'title': (str,),  # noqa: E501
            'cancel_reason': (str,),  # noqa: E501
            'percent_complete': (int,),  # noqa: E501
            'run_duration': (int,),  # noqa: E501
            'events': ([VirtualizationJobEvent],),  # noqa: E501
        }

    @cached_property
    def discriminator():
        return None


    attribute_map = {
        'engine_job_id': 'engine_job_id',  # noqa: E501
        'engine_id': 'engine_id',  # noqa: E501
        'legacy_job_type': 'legacy_job_type',  # noqa: E501
        'job_type': 'job_type',  # noqa: E501
        'target_object_id': 'target_object_id',  # noqa: E501
        'legacy_target_object_type': 'legacy_target_object_type',  # noqa: E501
        'target_object_type': 'target_object_type',  # noqa: E501
        'job_state': 'job_state',  # noqa: E501
        'start_time': 'start_time',  # noqa: E501
        'update_time': 'update_time',  # noqa: E501
        'suspendable': 'suspendable',  # noqa: E501
        'cancelable': 'cancelable',  # noqa: E501
        'queued': 'queued',  # noqa: E501
        'title': 'title',  # noqa: E501
        'cancel_reason': 'cancel_reason',  # noqa: E501
        'percent_complete': 'percent_complete',  # noqa: E501
        'run_duration': 'run_duration',  # noqa: E501
        'events': 'events',  # noqa: E501
    }

    read_only_vars = {
    }

    _composed_schemas = {}

    @classmethod
    @convert_js_args_to_python_args
    def _from_openapi_data(cls, *args, **kwargs):  # noqa: E501
        """VirtualizationJob - a model defined in OpenAPI

        Keyword Args:
            _check_type (bool): if True, values for parameters in openapi_types
                                will be type checked and a TypeError will be
                                raised if the wrong type is input.
                                Defaults to True
            _path_to_item (tuple/list): This is a list of keys or values to
                                drill down to the model in received_data
                                when deserializing a response
            _spec_property_naming (bool): True if the variable names in the input data
                                are serialized names, as specified in the OpenAPI document.
                                False if the variable names in the input data
                                are pythonic names, e.g. snake case (default)
            _configuration (Configuration): the instance to use when
                                deserializing a file_type parameter.
                                If passed, type conversion is attempted
                                If omitted no type conversion is done.
            _visited_composed_classes (tuple): This stores a tuple of
                                classes that we have traveled through so that
                                if we see that class again we will not use its
                                discriminator again.
                                When traveling through a discriminator, the
                                composed schema that is
                                is traveled through is added to this set.
                                For example if Animal has a discriminator
                                petType and we pass in "Dog", and the class Dog
                                allOf includes Animal, we move through Animal
                                once using the discriminator, and pick Dog.
                                Then in Dog, we will make an instance of the
                                Animal class but this time we won't travel
                                through its discriminator because we passed in
                                _visited_composed_classes = (Animal,)
            engine_job_id (str): ID of the virtualization engine job.. [optional]  # noqa: E501
            engine_id (str): ID of the RegisteredEngine.. [optional]  # noqa: E501
            legacy_job_type (str): Legacy type of the job.. [optional]  # noqa: E501
            job_type (TargetJobType): [optional]  # noqa: E501
            target_object_id (str): ID of the target object.. [optional]  # noqa: E501
            legacy_target_object_type (str): Legacy type of the target object.. [optional]  # noqa: E501
            target_object_type (TargetObjectType): [optional]  # noqa: E501
            job_state (str): [optional]  # noqa: E501
            start_time (datetime): The time the job started.. [optional]  # noqa: E501
            update_time (datetime): The time the job was last updated.. [optional]  # noqa: E501
            suspendable (bool): Indicates whether the job can be suspended.. [optional]  # noqa: E501
            cancelable (bool): Indicates whether the job can be canceled.. [optional]  # noqa: E501
            queued (bool): Indicates whether the job is queued.. [optional]  # noqa: E501
            title (str): The title of the job.. [optional]  # noqa: E501
            cancel_reason (str): The reason the job was canceled.. [optional]  # noqa: E501
            percent_complete (int): The percentage of the job that is complete.. [optional]  # noqa: E501
            run_duration (int): The time this job took to complete in milliseconds.. [optional]  # noqa: E501
            events ([VirtualizationJobEvent]): The events associated with this job.. [optional]  # noqa: E501
        """

        _check_type = kwargs.pop('_check_type', True)
        _spec_property_naming = kwargs.pop('_spec_property_naming', False)
        _path_to_item = kwargs.pop('_path_to_item', ())
        _configuration = kwargs.pop('_configuration', None)
        _visited_composed_classes = kwargs.pop('_visited_composed_classes', ())

        self = super(OpenApiModel, cls).__new__(cls)

        if args:
            raise ApiTypeError(
                "Invalid positional arguments=%s passed to %s. Remove those invalid positional arguments." % (
                    args,
                    self.__class__.__name__,
                ),
                path_to_item=_path_to_item,
                valid_classes=(self.__class__,),
            )

        self._data_store = {}
        self._check_type = _check_type
        self._spec_property_naming = _spec_property_naming
        self._path_to_item = _path_to_item
        self._configuration = _configuration
        self._visited_composed_classes = _visited_composed_classes + (self.__class__,)

        for var_name, var_value in kwargs.items():
            if var_name not in self.attribute_map and \
                        self._configuration is not None and \
                        self._configuration.discard_unknown_keys and \
                        self.additional_properties_type is None:
                # discard variable.
                continue
            setattr(self, var_name, var_value)
        return self

    required_properties = set([
        '_data_store',
        '_check_type',
        '_spec_property_naming',
        '_path_to_item',
        '_configuration',
        '_visited_composed_classes',
    ])

    @convert_js_args_to_python_args
    def __init__(self, *args, **kwargs):  # noqa: E501
        """VirtualizationJob - a model defined in OpenAPI

        Keyword Args:
            _check_type (bool): if True, values for parameters in openapi_types
                                will be type checked and a TypeError will be
                                raised if the wrong type is input.
                                Defaults to True
            _path_to_item (tuple/list): This is a list of keys or values to
                                drill down to the model in received_data
                                when deserializing a response
            _spec_property_naming (bool): True if the variable names in the input data
                                are serialized names, as specified in the OpenAPI document.
                                False if the variable names in the input data
                                are pythonic names, e.g. snake case (default)
            _configuration (Configuration): the instance to use when
                                deserializing a file_type parameter.
                                If passed, type conversion is attempted
                                If omitted no type conversion is done.
            _visited_composed_classes (tuple): This stores a tuple of
                                classes that we have traveled through so that
                                if we see that class again we will not use its
                                discriminator again.
                                When traveling through a discriminator, the
                                composed schema that is
                                is traveled through is added to this set.
                                For example if Animal has a discriminator
                                petType and we pass in "Dog", and the class Dog
                                allOf includes Animal, we move through Animal
                                once using the discriminator, and pick Dog.
                                Then in Dog, we will make an instance of the
                                Animal class but this time we won't travel
                                through its discriminator because we passed in
                                _visited_composed_classes = (Animal,)
            engine_job_id (str): ID of the virtualization engine job.. [optional]  # noqa: E501
            engine_id (str): ID of the RegisteredEngine.. [optional]  # noqa: E501
            legacy_job_type (str): Legacy type of the job.. [optional]  # noqa: E501
            job_type (TargetJobType): [optional]  # noqa: E501
            target_object_id (str): ID of the target object.. [optional]  # noqa: E501
            legacy_target_object_type (str): Legacy type of the target object.. [optional]  # noqa: E501
            target_object_type (TargetObjectType): [optional]  # noqa: E501
            job_state (str): [optional]  # noqa: E501
            start_time (datetime): The time the job started.. [optional]  # noqa: E501
            update_time (datetime): The time the job was last updated.. [optional]  # noqa: E501
            suspendable (bool): Indicates whether the job can be suspended.. [optional]  # noqa: E501
            cancelable (bool): Indicates whether the job can be canceled.. [optional]  # noqa: E501
            queued (bool): Indicates whether the job is queued.. [optional]  # noqa: E501
            title (str): The title of the job.. [optional]  # noqa: E501
            cancel_reason (str): The reason the job was canceled.. [optional]  # noqa: E501
            percent_complete (int): The percentage of the job that is complete.. [optional]  # noqa: E501
            run_duration (int): The time this job took to complete in milliseconds.. [optional]  # noqa: E501
            events ([VirtualizationJobEvent]): The events associated with this job.. [optional]  # noqa: E501
        """

        _check_type = kwargs.pop('_check_type', True)
        _spec_property_naming = kwargs.pop('_spec_property_naming', False)
        _path_to_item = kwargs.pop('_path_to_item', ())
        _configuration = kwargs.pop('_configuration', None)
        _visited_composed_classes = kwargs.pop('_visited_composed_classes', ())

        if args:
            raise ApiTypeError(
                "Invalid positional arguments=%s passed to %s. Remove those invalid positional arguments." % (
                    args,
                    self.__class__.__name__,
                ),
                path_to_item=_path_to_item,
                valid_classes=(self.__class__,),
            )

        self._data_store = {}
        self._check_type = _check_type
        self._spec_property_naming = _spec_property_naming
        self._path_to_item = _path_to_item
        self._configuration = _configuration
        self._visited_composed_classes = _visited_composed_classes + (self.__class__,)

        for var_name, var_value in kwargs.items():
            if var_name not in self.attribute_map and \
                        self._configuration is not None and \
                        self._configuration.discard_unknown_keys and \
                        self.additional_properties_type is None:
                # discard variable.
                continue
            setattr(self, var_name, var_value)
            if var_name in self.read_only_vars:
                raise ApiAttributeError(f"`{var_name}` is a read-only attribute. Use `from_openapi_data` to instantiate "
                                     f"class with read only attributes.")



"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.24.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import delphix.api.gateway
from delphix.api.gateway.model.create_role import CreateRole
from delphix.api.gateway.model.permission_object import PermissionObject
from delphix.api.gateway.model.role_all_of import RoleAllOf
from delphix.api.gateway.model.tag import Tag
globals()['CreateRole'] = CreateRole
globals()['PermissionObject'] = PermissionObject
globals()['RoleAllOf'] = RoleAllOf
globals()['Tag'] = Tag
from delphix.api.gateway.model.role import Role


class TestRole(unittest.TestCase):
    """Role unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testRole(self):
        """Test Role"""
        # FIXME: construct object with mandatory attributes with example values
        # model = Role()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.24.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from delphix.api.gateway.api_client import ApiClient, Endpoint as _Endpoint
from delphix.api.gateway.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from delphix.api.gateway.model.create_vdb_group_request import CreateVDBGroupRequest
from delphix.api.gateway.model.create_vdb_group_response import CreateVDBGroupResponse
from delphix.api.gateway.model.delete_tag import DeleteTag
from delphix.api.gateway.model.disable_vdb_group_parameters import DisableVDBGroupParameters
from delphix.api.gateway.model.disable_vdb_group_response import DisableVDBGroupResponse
from delphix.api.gateway.model.enable_vdb_group_parameters import EnableVDBGroupParameters
from delphix.api.gateway.model.enable_vdb_group_response import EnableVDBGroupResponse
from delphix.api.gateway.model.latest_snapshots_response import LatestSnapshotsResponse
from delphix.api.gateway.model.list_bookmarks_by_vdb_groups_response import ListBookmarksByVDBGroupsResponse
from delphix.api.gateway.model.list_vdb_groups_response import ListVDBGroupsResponse
from delphix.api.gateway.model.lock_vdb_group_parameters import LockVDBGroupParameters
from delphix.api.gateway.model.provision_vdb_group_from_bookmark_parameters import ProvisionVDBGroupFromBookmarkParameters
from delphix.api.gateway.model.provision_vdb_group_from_bookmark_response import ProvisionVDBGroupFromBookmarkResponse
from delphix.api.gateway.model.refresh_vdb_group_by_snapshot_parameters import RefreshVDBGroupBySnapshotParameters
from delphix.api.gateway.model.refresh_vdb_group_by_timestamp_parameters import RefreshVDBGroupByTimestampParameters
from delphix.api.gateway.model.refresh_vdb_group_parameters import RefreshVDBGroupParameters
from delphix.api.gateway.model.refresh_vdb_group_response import RefreshVDBGroupResponse
from delphix.api.gateway.model.rollback_vdb_group_parameters import RollbackVDBGroupParameters
from delphix.api.gateway.model.rollback_vdb_group_response import RollbackVDBGroupResponse
from delphix.api.gateway.model.search_body import SearchBody
from delphix.api.gateway.model.search_bookmarks_by_vdb_groups_response import SearchBookmarksByVDBGroupsResponse
from delphix.api.gateway.model.search_vdb_group_response import SearchVDBGroupResponse
from delphix.api.gateway.model.start_vdb_group_parameters import StartVDBGroupParameters
from delphix.api.gateway.model.start_vdb_group_response import StartVDBGroupResponse
from delphix.api.gateway.model.stop_vdb_group_parameters import StopVDBGroupParameters
from delphix.api.gateway.model.stop_vdb_group_response import StopVDBGroupResponse
from delphix.api.gateway.model.tags_request import TagsRequest
from delphix.api.gateway.model.tags_response import TagsResponse
from delphix.api.gateway.model.update_vdb_group_parameters import UpdateVDBGroupParameters
from delphix.api.gateway.model.vdb_group import VDBGroup
from delphix.api.gateway.model.vdb_group_timestamp_summary_request import VDBGroupTimestampSummaryRequest
from delphix.api.gateway.model.vdb_group_timestamp_summary_response import VdbGroupTimestampSummaryResponse


class VDBGroupsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

        def __create_vdb_group(
            self,
            create_vdb_group_request,
            **kwargs
        ):
            """Create a new VDB Group.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.create_vdb_group(create_vdb_group_request, async_req=True)
            >>> result = thread.get()

            Args:
                create_vdb_group_request (CreateVDBGroupRequest):

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                CreateVDBGroupResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['create_vdb_group_request'] = \
                create_vdb_group_request
            return self.call_with_http_info(**kwargs)

        self.create_vdb_group = _Endpoint(
            settings={
                'response_type': (CreateVDBGroupResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/vdb-groups',
                'operation_id': 'create_vdb_group',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'create_vdb_group_request',
                ],
                'required': [
                    'create_vdb_group_request',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'create_vdb_group_request':
                        (CreateVDBGroupRequest,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'create_vdb_group_request': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__create_vdb_group
        )

        def __create_vdb_groups_tags(
            self,
            vdb_group_id,
            tags_request,
            **kwargs
        ):
            """Create tags for a VDB Group.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.create_vdb_groups_tags(vdb_group_id, tags_request, async_req=True)
            >>> result = thread.get()

            Args:
                vdb_group_id (str): The ID or name of the VDB Group.
                tags_request (TagsRequest): Tags information for VDB Group.

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                TagsResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['vdb_group_id'] = \
                vdb_group_id
            kwargs['tags_request'] = \
                tags_request
            return self.call_with_http_info(**kwargs)

        self.create_vdb_groups_tags = _Endpoint(
            settings={
                'response_type': (TagsResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/vdb-groups/{vdbGroupId}/tags',
                'operation_id': 'create_vdb_groups_tags',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'vdb_group_id',
                    'tags_request',
                ],
                'required': [
                    'vdb_group_id',
                    'tags_request',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'vdb_group_id',
                ]
            },
            root_map={
                'validations': {
                    ('vdb_group_id',): {
                        'max_length': 256,
                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'vdb_group_id':
                        (str,),
                    'tags_request':
                        (TagsRequest,),
                },
                'attribute_map': {
                    'vdb_group_id': 'vdbGroupId',
                },
                'location_map': {
                    'vdb_group_id': 'path',
                    'tags_request': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__create_vdb_groups_tags
        )

        def __delete_vdb_group(
            self,
            vdb_group_id,
            **kwargs
        ):
            """Delete a VDBGoup.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.delete_vdb_group(vdb_group_id, async_req=True)
            >>> result = thread.get()

            Args:
                vdb_group_id (str): The ID or name of the VDB Group.

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                None
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['vdb_group_id'] = \
                vdb_group_id
            return self.call_with_http_info(**kwargs)

        self.delete_vdb_group = _Endpoint(
            settings={
                'response_type': None,
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/vdb-groups/{vdbGroupId}',
                'operation_id': 'delete_vdb_group',
                'http_method': 'DELETE',
                'servers': None,
            },
            params_map={
                'all': [
                    'vdb_group_id',
                ],
                'required': [
                    'vdb_group_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'vdb_group_id',
                ]
            },
            root_map={
                'validations': {
                    ('vdb_group_id',): {
                        'max_length': 256,
                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'vdb_group_id':
                        (str,),
                },
                'attribute_map': {
                    'vdb_group_id': 'vdbGroupId',
                },
                'location_map': {
                    'vdb_group_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [],
                'content_type': [],
            },
            api_client=api_client,
            callable=__delete_vdb_group
        )

        def __delete_vdb_group_tags(
            self,
            vdb_group_id,
            **kwargs
        ):
            """Delete tags for a VDB Group.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.delete_vdb_group_tags(vdb_group_id, async_req=True)
            >>> result = thread.get()

            Args:
                vdb_group_id (str): The ID or name of the VDB Group.

            Keyword Args:
                delete_tag (DeleteTag): The parameters to delete tags. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                None
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['vdb_group_id'] = \
                vdb_group_id
            return self.call_with_http_info(**kwargs)

        self.delete_vdb_group_tags = _Endpoint(
            settings={
                'response_type': None,
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/vdb-groups/{vdbGroupId}/tags/delete',
                'operation_id': 'delete_vdb_group_tags',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'vdb_group_id',
                    'delete_tag',
                ],
                'required': [
                    'vdb_group_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'vdb_group_id',
                ]
            },
            root_map={
                'validations': {
                    ('vdb_group_id',): {
                        'max_length': 256,
                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'vdb_group_id':
                        (str,),
                    'delete_tag':
                        (DeleteTag,),
                },
                'attribute_map': {
                    'vdb_group_id': 'vdbGroupId',
                },
                'location_map': {
                    'vdb_group_id': 'path',
                    'delete_tag': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__delete_vdb_group_tags
        )

        def __disable_vdb_group(
            self,
            vdb_group_id,
            **kwargs
        ):
            """Disable a VDB Group.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.disable_vdb_group(vdb_group_id, async_req=True)
            >>> result = thread.get()

            Args:
                vdb_group_id (str): The ID or name of the VDB Group.

            Keyword Args:
                disable_vdb_group_parameters (DisableVDBGroupParameters): The parameters to disable a VDB Group.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                DisableVDBGroupResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['vdb_group_id'] = \
                vdb_group_id
            return self.call_with_http_info(**kwargs)

        self.disable_vdb_group = _Endpoint(
            settings={
                'response_type': (DisableVDBGroupResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/vdb-groups/{vdbGroupId}/disable',
                'operation_id': 'disable_vdb_group',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'vdb_group_id',
                    'disable_vdb_group_parameters',
                ],
                'required': [
                    'vdb_group_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'vdb_group_id',
                ]
            },
            root_map={
                'validations': {
                    ('vdb_group_id',): {
                        'max_length': 256,
                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'vdb_group_id':
                        (str,),
                    'disable_vdb_group_parameters':
                        (DisableVDBGroupParameters,),
                },
                'attribute_map': {
                    'vdb_group_id': 'vdbGroupId',
                },
                'location_map': {
                    'vdb_group_id': 'path',
                    'disable_vdb_group_parameters': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__disable_vdb_group
        )

        def __enable_vdb_group(
            self,
            vdb_group_id,
            **kwargs
        ):
            """Enable a VDB Group.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.enable_vdb_group(vdb_group_id, async_req=True)
            >>> result = thread.get()

            Args:
                vdb_group_id (str): The ID or name of the VDB Group.

            Keyword Args:
                enable_vdb_group_parameters (EnableVDBGroupParameters): The parameters to enable a VDB Group.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                EnableVDBGroupResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['vdb_group_id'] = \
                vdb_group_id
            return self.call_with_http_info(**kwargs)

        self.enable_vdb_group = _Endpoint(
            settings={
                'response_type': (EnableVDBGroupResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/vdb-groups/{vdbGroupId}/enable',
                'operation_id': 'enable_vdb_group',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'vdb_group_id',
                    'enable_vdb_group_parameters',
                ],
                'required': [
                    'vdb_group_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'vdb_group_id',
                ]
            },
            root_map={
                'validations': {
                    ('vdb_group_id',): {
                        'max_length': 256,
                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'vdb_group_id':
                        (str,),
                    'enable_vdb_group_parameters':
                        (EnableVDBGroupParameters,),
                },
                'attribute_map': {
                    'vdb_group_id': 'vdbGroupId',
                },
                'location_map': {
                    'vdb_group_id': 'path',
                    'enable_vdb_group_parameters': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__enable_vdb_group
        )

        def __get_bookmarks_by_vdb_group(
            self,
            vdb_group_id,
            **kwargs
        ):
            """List bookmarks compatible with this VDB Group.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_bookmarks_by_vdb_group(vdb_group_id, async_req=True)
            >>> result = thread.get()

            Args:
                vdb_group_id (str): The ID or name of the VDB Group.

            Keyword Args:
                limit (int): Maximum number of objects to return per query. The value must be between 1 and 1000. Default is 100.. [optional] if omitted the server will use the default value of 100
                cursor (str): Cursor to fetch the next or previous page of results. The value of this property must be extracted from the 'prev_cursor' or 'next_cursor' property of a PaginatedResponseMetadata which is contained in the response of list and search API endpoints.. [optional]
                sort (str, none_type): The field to sort results by. A property name with a prepended '-' signifies descending order.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                ListBookmarksByVDBGroupsResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['vdb_group_id'] = \
                vdb_group_id
            return self.call_with_http_info(**kwargs)

        self.get_bookmarks_by_vdb_group = _Endpoint(
            settings={
                'response_type': (ListBookmarksByVDBGroupsResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/vdb-groups/{vdbGroupId}/bookmarks',
                'operation_id': 'get_bookmarks_by_vdb_group',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'vdb_group_id',
                    'limit',
                    'cursor',
                    'sort',
                ],
                'required': [
                    'vdb_group_id',
                ],
                'nullable': [
                    'sort',
                ],
                'enum': [
                    'sort',
                ],
                'validation': [
                    'vdb_group_id',
                    'limit',
                    'cursor',
                ]
            },
            root_map={
                'validations': {
                    ('vdb_group_id',): {
                        'max_length': 256,
                        'min_length': 1,
                    },
                    ('limit',): {

                        'inclusive_maximum': 1000,
                        'inclusive_minimum': 1,
                    },
                    ('cursor',): {
                        'max_length': 4096,
                        'min_length': 1,
                    },
                },
                'allowed_values': {
                    ('sort',): {
                        'None': None,
                        "ID": "id",
                        "-ID": "-id",
                        "NAME": "name",
                        "-NAME": "-name",
                        "CREATION_DATE": "creation_date",
                        "-CREATION_DATE": "-creation_date",
                        "VDB_IDS": "vdb_ids",
                        "-VDB_IDS": "-vdb_ids",
                        "RETENTION": "retention",
                        "-RETENTION": "-retention",
                        "EXPIRATION": "expiration",
                        "-EXPIRATION": "-expiration",
                        "DATA_TIMESTAMP": "data_timestamp",
                        "-DATA_TIMESTAMP": "-data_timestamp",
                        "TIMEFLOW_ID": "timeflow_id",
                        "-TIMEFLOW_ID": "-timeflow_id",
                        "LOCATION": "location",
                        "-LOCATION": "-location",
                        "VDB_GROUP_NAME": "vdb_group_name",
                        "-VDB_GROUP_NAME": "-vdb_group_name"
                    },
                },
                'openapi_types': {
                    'vdb_group_id':
                        (str,),
                    'limit':
                        (int,),
                    'cursor':
                        (str,),
                    'sort':
                        (str, none_type,),
                },
                'attribute_map': {
                    'vdb_group_id': 'vdbGroupId',
                    'limit': 'limit',
                    'cursor': 'cursor',
                    'sort': 'sort',
                },
                'location_map': {
                    'vdb_group_id': 'path',
                    'limit': 'query',
                    'cursor': 'query',
                    'sort': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__get_bookmarks_by_vdb_group
        )

        def __get_vdb_group(
            self,
            vdb_group_id,
            **kwargs
        ):
            """Get a VDB Group by name.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_vdb_group(vdb_group_id, async_req=True)
            >>> result = thread.get()

            Args:
                vdb_group_id (str): The ID or name of the VDB Group.

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                VDBGroup
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['vdb_group_id'] = \
                vdb_group_id
            return self.call_with_http_info(**kwargs)

        self.get_vdb_group = _Endpoint(
            settings={
                'response_type': (VDBGroup,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/vdb-groups/{vdbGroupId}',
                'operation_id': 'get_vdb_group',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'vdb_group_id',
                ],
                'required': [
                    'vdb_group_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'vdb_group_id',
                ]
            },
            root_map={
                'validations': {
                    ('vdb_group_id',): {
                        'max_length': 256,
                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'vdb_group_id':
                        (str,),
                },
                'attribute_map': {
                    'vdb_group_id': 'vdbGroupId',
                },
                'location_map': {
                    'vdb_group_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__get_vdb_group
        )

        def __get_vdb_group_tags(
            self,
            vdb_group_id,
            **kwargs
        ):
            """Get tags for a VDB Group.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_vdb_group_tags(vdb_group_id, async_req=True)
            >>> result = thread.get()

            Args:
                vdb_group_id (str): The ID or name of the VDB Group.

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                TagsResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['vdb_group_id'] = \
                vdb_group_id
            return self.call_with_http_info(**kwargs)

        self.get_vdb_group_tags = _Endpoint(
            settings={
                'response_type': (TagsResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/vdb-groups/{vdbGroupId}/tags',
                'operation_id': 'get_vdb_group_tags',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'vdb_group_id',
                ],
                'required': [
                    'vdb_group_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'vdb_group_id',
                ]
            },
            root_map={
                'validations': {
                    ('vdb_group_id',): {
                        'max_length': 256,
                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'vdb_group_id':
                        (str,),
                },
                'attribute_map': {
                    'vdb_group_id': 'vdbGroupId',
                },
                'location_map': {
                    'vdb_group_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__get_vdb_group_tags
        )

        def __get_vdb_group_timestamp_summary(
            self,
            vdb_group_id,
            **kwargs
        ):
            """Get timestamp summary of all the vdbs in VDB Group.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_vdb_group_timestamp_summary(vdb_group_id, async_req=True)
            >>> result = thread.get()

            Args:
                vdb_group_id (str): The ID or name of the VDB Group.

            Keyword Args:
                vdb_group_timestamp_summary_request (VDBGroupTimestampSummaryRequest): [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                VdbGroupTimestampSummaryResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['vdb_group_id'] = \
                vdb_group_id
            return self.call_with_http_info(**kwargs)

        self.get_vdb_group_timestamp_summary = _Endpoint(
            settings={
                'response_type': (VdbGroupTimestampSummaryResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/vdb-groups/{vdbGroupId}/timestamp-summary',
                'operation_id': 'get_vdb_group_timestamp_summary',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'vdb_group_id',
                    'vdb_group_timestamp_summary_request',
                ],
                'required': [
                    'vdb_group_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'vdb_group_id',
                ]
            },
            root_map={
                'validations': {
                    ('vdb_group_id',): {
                        'max_length': 256,
                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'vdb_group_id':
                        (str,),
                    'vdb_group_timestamp_summary_request':
                        (VDBGroupTimestampSummaryRequest,),
                },
                'attribute_map': {
                    'vdb_group_id': 'vdbGroupId',
                },
                'location_map': {
                    'vdb_group_id': 'path',
                    'vdb_group_timestamp_summary_request': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__get_vdb_group_timestamp_summary
        )

        def __get_vdb_group_vdbs_latest_snapshots(
            self,
            vdb_group_id,
            **kwargs
        ):
            """Get latest snapshot of all the vdbs in VDB Group.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_vdb_group_vdbs_latest_snapshots(vdb_group_id, async_req=True)
            >>> result = thread.get()

            Args:
                vdb_group_id (str): The ID or name of the VDB Group.

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                LatestSnapshotsResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['vdb_group_id'] = \
                vdb_group_id
            return self.call_with_http_info(**kwargs)

        self.get_vdb_group_vdbs_latest_snapshots = _Endpoint(
            settings={
                'response_type': (LatestSnapshotsResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/vdb-groups/{vdbGroupId}/latest-snapshots',
                'operation_id': 'get_vdb_group_vdbs_latest_snapshots',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'vdb_group_id',
                ],
                'required': [
                    'vdb_group_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'vdb_group_id',
                ]
            },
            root_map={
                'validations': {
                    ('vdb_group_id',): {
                        'max_length': 256,
                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'vdb_group_id':
                        (str,),
                },
                'attribute_map': {
                    'vdb_group_id': 'vdbGroupId',
                },
                'location_map': {
                    'vdb_group_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__get_vdb_group_vdbs_latest_snapshots
        )

        def __get_vdb_groups(
            self,
            **kwargs
        ):
            """List all VDBGroups.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_vdb_groups(async_req=True)
            >>> result = thread.get()


            Keyword Args:
                limit (int): Maximum number of objects to return per query. The value must be between 1 and 1000. Default is 100.. [optional] if omitted the server will use the default value of 100
                cursor (str): Cursor to fetch the next or previous page of results. The value of this property must be extracted from the 'prev_cursor' or 'next_cursor' property of a PaginatedResponseMetadata which is contained in the response of list and search API endpoints.. [optional]
                sort (str, none_type): The field to sort results by. A property name with a prepended '-' signifies descending order.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                ListVDBGroupsResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            return self.call_with_http_info(**kwargs)

        self.get_vdb_groups = _Endpoint(
            settings={
                'response_type': (ListVDBGroupsResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/vdb-groups',
                'operation_id': 'get_vdb_groups',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'limit',
                    'cursor',
                    'sort',
                ],
                'required': [],
                'nullable': [
                    'sort',
                ],
                'enum': [
                    'sort',
                ],
                'validation': [
                    'limit',
                    'cursor',
                ]
            },
            root_map={
                'validations': {
                    ('limit',): {

                        'inclusive_maximum': 1000,
                        'inclusive_minimum': 1,
                    },
                    ('cursor',): {
                        'max_length': 4096,
                        'min_length': 1,
                    },
                },
                'allowed_values': {
                    ('sort',): {
                        'None': None,
                        "ID": "id",
                        "-ID": "-id",
                        "NAME": "name",
                        "-NAME": "-name",
                        "LOCKED_BY": "locked_by",
                        "-LOCKED_BY": "-locked_by",
                        "LOCKED_BY_NAME": "locked_by_name",
                        "-LOCKED_BY_NAME": "-locked_by_name",
                        "DATABASE_TYPE": "database_type",
                        "-DATABASE_TYPE": "-database_type",
                        "STATUS": "status",
                        "-STATUS": "-status",
                        "LAST_SUCCESSFUL_REFRESH_TO_BOOKMARK_ID": "last_successful_refresh_to_bookmark_id",
                        "-LAST_SUCCESSFUL_REFRESH_TO_BOOKMARK_ID": "-last_successful_refresh_to_bookmark_id",
                        "LAST_SUCCESSFUL_REFRESH_TIME": "last_successful_refresh_time",
                        "-LAST_SUCCESSFUL_REFRESH_TIME": "-last_successful_refresh_time"
                    },
                },
                'openapi_types': {
                    'limit':
                        (int,),
                    'cursor':
                        (str,),
                    'sort':
                        (str, none_type,),
                },
                'attribute_map': {
                    'limit': 'limit',
                    'cursor': 'cursor',
                    'sort': 'sort',
                },
                'location_map': {
                    'limit': 'query',
                    'cursor': 'query',
                    'sort': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__get_vdb_groups
        )

        def __lock_vdb_group(
            self,
            vdb_group_id,
            lock_vdb_group_parameters,
            **kwargs
        ):
            """Lock a VDB Group.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.lock_vdb_group(vdb_group_id, lock_vdb_group_parameters, async_req=True)
            >>> result = thread.get()

            Args:
                vdb_group_id (str): The ID or name of the VDB Group.
                lock_vdb_group_parameters (LockVDBGroupParameters):

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                VDBGroup
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['vdb_group_id'] = \
                vdb_group_id
            kwargs['lock_vdb_group_parameters'] = \
                lock_vdb_group_parameters
            return self.call_with_http_info(**kwargs)

        self.lock_vdb_group = _Endpoint(
            settings={
                'response_type': (VDBGroup,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/vdb-groups/{vdbGroupId}/lock',
                'operation_id': 'lock_vdb_group',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'vdb_group_id',
                    'lock_vdb_group_parameters',
                ],
                'required': [
                    'vdb_group_id',
                    'lock_vdb_group_parameters',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'vdb_group_id',
                ]
            },
            root_map={
                'validations': {
                    ('vdb_group_id',): {
                        'max_length': 256,
                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'vdb_group_id':
                        (str,),
                    'lock_vdb_group_parameters':
                        (LockVDBGroupParameters,),
                },
                'attribute_map': {
                    'vdb_group_id': 'vdbGroupId',
                },
                'location_map': {
                    'vdb_group_id': 'path',
                    'lock_vdb_group_parameters': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__lock_vdb_group
        )

        def __provision_vdb_group_from_bookmark(
            self,
            **kwargs
        ):
            """Provision a new VDB Group from a Bookmark.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.provision_vdb_group_from_bookmark(async_req=True)
            >>> result = thread.get()


            Keyword Args:
                provision_vdb_group_from_bookmark_parameters (ProvisionVDBGroupFromBookmarkParameters): The parameters to provision a VDB group from a Bookmark.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                ProvisionVDBGroupFromBookmarkResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            return self.call_with_http_info(**kwargs)

        self.provision_vdb_group_from_bookmark = _Endpoint(
            settings={
                'response_type': (ProvisionVDBGroupFromBookmarkResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/vdb-groups/provision_from_bookmark',
                'operation_id': 'provision_vdb_group_from_bookmark',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'provision_vdb_group_from_bookmark_parameters',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'provision_vdb_group_from_bookmark_parameters':
                        (ProvisionVDBGroupFromBookmarkParameters,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'provision_vdb_group_from_bookmark_parameters': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__provision_vdb_group_from_bookmark
        )

        def __refresh_vdb_group(
            self,
            vdb_group_id,
            **kwargs
        ):
            """Refresh a VDB Group from bookmark.  # noqa: E501

            This API is marked as deprecated in favour of renamed API '/vdb-groups/{vdbGroupId}/refresh_from_bookmark'  # noqa: E501
            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.refresh_vdb_group(vdb_group_id, async_req=True)
            >>> result = thread.get()

            Args:
                vdb_group_id (str): The ID or name of the VDB Group.

            Keyword Args:
                refresh_vdb_group_parameters (RefreshVDBGroupParameters): The parameters to refresh a VDB Group.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                RefreshVDBGroupResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['vdb_group_id'] = \
                vdb_group_id
            return self.call_with_http_info(**kwargs)

        self.refresh_vdb_group = _Endpoint(
            settings={
                'response_type': (RefreshVDBGroupResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/vdb-groups/{vdbGroupId}/refresh',
                'operation_id': 'refresh_vdb_group',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'vdb_group_id',
                    'refresh_vdb_group_parameters',
                ],
                'required': [
                    'vdb_group_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'vdb_group_id',
                ]
            },
            root_map={
                'validations': {
                    ('vdb_group_id',): {
                        'max_length': 256,
                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'vdb_group_id':
                        (str,),
                    'refresh_vdb_group_parameters':
                        (RefreshVDBGroupParameters,),
                },
                'attribute_map': {
                    'vdb_group_id': 'vdbGroupId',
                },
                'location_map': {
                    'vdb_group_id': 'path',
                    'refresh_vdb_group_parameters': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__refresh_vdb_group
        )

        def __refresh_vdb_group_by_snapshot(
            self,
            vdb_group_id,
            **kwargs
        ):
            """Refresh a VDB Group by snapshot.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.refresh_vdb_group_by_snapshot(vdb_group_id, async_req=True)
            >>> result = thread.get()

            Args:
                vdb_group_id (str): The ID or name of the VDB Group.

            Keyword Args:
                refresh_vdb_group_by_snapshot_parameters (RefreshVDBGroupBySnapshotParameters): The parameters to refresh a VDB Group by snapshot.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                RefreshVDBGroupResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['vdb_group_id'] = \
                vdb_group_id
            return self.call_with_http_info(**kwargs)

        self.refresh_vdb_group_by_snapshot = _Endpoint(
            settings={
                'response_type': (RefreshVDBGroupResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/vdb-groups/{vdbGroupId}/refresh_by_snapshot',
                'operation_id': 'refresh_vdb_group_by_snapshot',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'vdb_group_id',
                    'refresh_vdb_group_by_snapshot_parameters',
                ],
                'required': [
                    'vdb_group_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'vdb_group_id',
                ]
            },
            root_map={
                'validations': {
                    ('vdb_group_id',): {
                        'max_length': 256,
                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'vdb_group_id':
                        (str,),
                    'refresh_vdb_group_by_snapshot_parameters':
                        (RefreshVDBGroupBySnapshotParameters,),
                },
                'attribute_map': {
                    'vdb_group_id': 'vdbGroupId',
                },
                'location_map': {
                    'vdb_group_id': 'path',
                    'refresh_vdb_group_by_snapshot_parameters': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__refresh_vdb_group_by_snapshot
        )

        def __refresh_vdb_group_by_timestamp(
            self,
            vdb_group_id,
            **kwargs
        ):
            """Refresh a VDB Group by timestamp.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.refresh_vdb_group_by_timestamp(vdb_group_id, async_req=True)
            >>> result = thread.get()

            Args:
                vdb_group_id (str): The ID or name of the VDB Group.

            Keyword Args:
                refresh_vdb_group_by_timestamp_parameters (RefreshVDBGroupByTimestampParameters): The parameters to refresh a VDB Group by timestamp.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                RefreshVDBGroupResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['vdb_group_id'] = \
                vdb_group_id
            return self.call_with_http_info(**kwargs)

        self.refresh_vdb_group_by_timestamp = _Endpoint(
            settings={
                'response_type': (RefreshVDBGroupResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/vdb-groups/{vdbGroupId}/refresh_by_timestamp',
                'operation_id': 'refresh_vdb_group_by_timestamp',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'vdb_group_id',
                    'refresh_vdb_group_by_timestamp_parameters',
                ],
                'required': [
                    'vdb_group_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'vdb_group_id',
                ]
            },
            root_map={
                'validations': {
                    ('vdb_group_id',): {
                        'max_length': 256,
                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'vdb_group_id':
                        (str,),
                    'refresh_vdb_group_by_timestamp_parameters':
                        (RefreshVDBGroupByTimestampParameters,),
                },
                'attribute_map': {
                    'vdb_group_id': 'vdbGroupId',
                },
                'location_map': {
                    'vdb_group_id': 'path',
                    'refresh_vdb_group_by_timestamp_parameters': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__refresh_vdb_group_by_timestamp
        )

        def __refresh_vdb_group_from_bookmark(
            self,
            vdb_group_id,
            **kwargs
        ):
            """Refresh a VDB Group from bookmark.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.refresh_vdb_group_from_bookmark(vdb_group_id, async_req=True)
            >>> result = thread.get()

            Args:
                vdb_group_id (str): The ID or name of the VDB Group.

            Keyword Args:
                refresh_vdb_group_parameters (RefreshVDBGroupParameters): The parameters to refresh a VDB Group.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                RefreshVDBGroupResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['vdb_group_id'] = \
                vdb_group_id
            return self.call_with_http_info(**kwargs)

        self.refresh_vdb_group_from_bookmark = _Endpoint(
            settings={
                'response_type': (RefreshVDBGroupResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/vdb-groups/{vdbGroupId}/refresh_from_bookmark',
                'operation_id': 'refresh_vdb_group_from_bookmark',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'vdb_group_id',
                    'refresh_vdb_group_parameters',
                ],
                'required': [
                    'vdb_group_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'vdb_group_id',
                ]
            },
            root_map={
                'validations': {
                    ('vdb_group_id',): {
                        'max_length': 256,
                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'vdb_group_id':
                        (str,),
                    'refresh_vdb_group_parameters':
                        (RefreshVDBGroupParameters,),
                },
                'attribute_map': {
                    'vdb_group_id': 'vdbGroupId',
                },
                'location_map': {
                    'vdb_group_id': 'path',
                    'refresh_vdb_group_parameters': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__refresh_vdb_group_from_bookmark
        )

        def __rollback_vdb_group(
            self,
            vdb_group_id,
            **kwargs
        ):
            """Rollback a VDB Group from a bookmark.  # noqa: E501

            This API is marked as deprecated in favour of API '/vdb-groups/{vdbGroupId}/refresh_from_bookmark'  # noqa: E501
            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.rollback_vdb_group(vdb_group_id, async_req=True)
            >>> result = thread.get()

            Args:
                vdb_group_id (str): The ID or name of the VDB Group.

            Keyword Args:
                rollback_vdb_group_parameters (RollbackVDBGroupParameters): The parameters to rollback a VDB Group.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                RollbackVDBGroupResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['vdb_group_id'] = \
                vdb_group_id
            return self.call_with_http_info(**kwargs)

        self.rollback_vdb_group = _Endpoint(
            settings={
                'response_type': (RollbackVDBGroupResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/vdb-groups/{vdbGroupId}/rollback',
                'operation_id': 'rollback_vdb_group',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'vdb_group_id',
                    'rollback_vdb_group_parameters',
                ],
                'required': [
                    'vdb_group_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'vdb_group_id',
                ]
            },
            root_map={
                'validations': {
                    ('vdb_group_id',): {
                        'max_length': 256,
                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'vdb_group_id':
                        (str,),
                    'rollback_vdb_group_parameters':
                        (RollbackVDBGroupParameters,),
                },
                'attribute_map': {
                    'vdb_group_id': 'vdbGroupId',
                },
                'location_map': {
                    'vdb_group_id': 'path',
                    'rollback_vdb_group_parameters': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__rollback_vdb_group
        )

        def __search_bookmarks_by_vdb_group(
            self,
            vdb_group_id,
            **kwargs
        ):
            """Search for bookmarks compatible with this VDB Group.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.search_bookmarks_by_vdb_group(vdb_group_id, async_req=True)
            >>> result = thread.get()

            Args:
                vdb_group_id (str): The ID or name of the VDB Group.

            Keyword Args:
                limit (int): Maximum number of objects to return per query. The value must be between 1 and 1000. Default is 100.. [optional] if omitted the server will use the default value of 100
                cursor (str): Cursor to fetch the next or previous page of results. The value of this property must be extracted from the 'prev_cursor' or 'next_cursor' property of a PaginatedResponseMetadata which is contained in the response of list and search API endpoints.. [optional]
                sort (str, none_type): The field to sort results by. A property name with a prepended '-' signifies descending order.. [optional]
                search_body (SearchBody): A request body containing a filter expression. This enables searching for items matching arbitrarily complex conditions. The list of attributes which can be used in filter expressions is available in the x-filterable vendor extension.  # Filter Expression Overview **Note: All keywords are case-insensitive**  ## Comparison Operators | Operator | Description | Example | | --- | --- | --- | | CONTAINS | Substring or membership testing for string and list attributes respectively. | field3 CONTAINS 'foobar', field4 CONTAINS TRUE  | | IN | Tests if field is a member of a list literal. List can contain a maximum of 100 values | field2 IN ['Goku', 'Vegeta'] | | GE | Tests if a field is greater than or equal to a literal value | field1 GE 1.2e-2 | | GT | Tests if a field is greater than a literal value | field1 GT 1.2e-2 | | LE | Tests if a field is less than or equal to a literal value | field1 LE 9000 | | LT | Tests if a field is less than a literal value | field1 LT 9.02 | | NE | Tests if a field is not equal to a literal value | field1 NE 42 | | EQ | Tests if a field is equal to a literal value | field1 EQ 42 |  ## Search Operator The SEARCH operator filters for items which have any filterable attribute that contains the input string as a substring, comparison is done case-insensitively. This is not restricted to attributes with string values. Specifically `SEARCH '12'` would match an item with an attribute with an integer value of `123`.  ## Logical Operators Ordered by precedence. | Operator | Description | Example | | --- | --- | --- | | NOT | Logical NOT (Right associative) | NOT field1 LE 9000 | | AND | Logical AND (Left Associative) | field1 GT 9000 AND field2 EQ 'Goku' | | OR | Logical OR (Left Associative) | field1 GT 9000 OR field2 EQ 'Goku' |  ## Grouping Parenthesis `()` can be used to override operator precedence.  For example: NOT (field1 LT 1234 AND field2 CONTAINS 'foo')  ## Literal Values | Literal      | Description | Examples | | --- | --- | --- | | Nil | Represents the absence of a value | nil, Nil, nIl, NIL | | Boolean | true/false boolean | true, false, True, False, TRUE, FALSE | | Number | Signed integer and floating point numbers. Also supports scientific notation. | 0, 1, -1, 1.2, 0.35, 1.2e-2, -1.2e+2 | | String | Single or double quoted | \"foo\", \"bar\", \"foo bar\", 'foo', 'bar', 'foo bar' | | Datetime | Formatted according to [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339) | 2018-04-27T18:39:26.397237+00:00 | | List | Comma-separated literals wrapped in square brackets | [0], [0, 1], ['foo', \"bar\"] |  ## Limitations - A maximum of 8 unique identifiers may be used inside a filter expression. . [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                SearchBookmarksByVDBGroupsResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['vdb_group_id'] = \
                vdb_group_id
            return self.call_with_http_info(**kwargs)

        self.search_bookmarks_by_vdb_group = _Endpoint(
            settings={
                'response_type': (SearchBookmarksByVDBGroupsResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/vdb-groups/{vdbGroupId}/bookmarks/search',
                'operation_id': 'search_bookmarks_by_vdb_group',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'vdb_group_id',
                    'limit',
                    'cursor',
                    'sort',
                    'search_body',
                ],
                'required': [
                    'vdb_group_id',
                ],
                'nullable': [
                    'sort',
                ],
                'enum': [
                    'sort',
                ],
                'validation': [
                    'vdb_group_id',
                    'limit',
                    'cursor',
                ]
            },
            root_map={
                'validations': {
                    ('vdb_group_id',): {
                        'max_length': 256,
                        'min_length': 1,
                    },
                    ('limit',): {

                        'inclusive_maximum': 1000,
                        'inclusive_minimum': 1,
                    },
                    ('cursor',): {
                        'max_length': 4096,
                        'min_length': 1,
                    },
                },
                'allowed_values': {
                    ('sort',): {
                        'None': None,
                        "ID": "id",
                        "-ID": "-id",
                        "NAME": "name",
                        "-NAME": "-name",
                        "CREATION_DATE": "creation_date",
                        "-CREATION_DATE": "-creation_date",
                        "VDB_IDS": "vdb_ids",
                        "-VDB_IDS": "-vdb_ids",
                        "RETENTION": "retention",
                        "-RETENTION": "-retention",
                        "EXPIRATION": "expiration",
                        "-EXPIRATION": "-expiration",
                        "DATA_TIMESTAMP": "data_timestamp",
                        "-DATA_TIMESTAMP": "-data_timestamp",
                        "TIMEFLOW_ID": "timeflow_id",
                        "-TIMEFLOW_ID": "-timeflow_id",
                        "LOCATION": "location",
                        "-LOCATION": "-location",
                        "VDB_GROUP_NAME": "vdb_group_name",
                        "-VDB_GROUP_NAME": "-vdb_group_name"
                    },
                },
                'openapi_types': {
                    'vdb_group_id':
                        (str,),
                    'limit':
                        (int,),
                    'cursor':
                        (str,),
                    'sort':
                        (str, none_type,),
                    'search_body':
                        (SearchBody,),
                },
                'attribute_map': {
                    'vdb_group_id': 'vdbGroupId',
                    'limit': 'limit',
                    'cursor': 'cursor',
                    'sort': 'sort',
                },
                'location_map': {
                    'vdb_group_id': 'path',
                    'limit': 'query',
                    'cursor': 'query',
                    'sort': 'query',
                    'search_body': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__search_bookmarks_by_vdb_group
        )

        def __search_vdb_groups(
            self,
            **kwargs
        ):
            """Search for VDB Groups.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.search_vdb_groups(async_req=True)
            >>> result = thread.get()


            Keyword Args:
                limit (int): Maximum number of objects to return per query. The value must be between 1 and 1000. Default is 100.. [optional] if omitted the server will use the default value of 100
                cursor (str): Cursor to fetch the next or previous page of results. The value of this property must be extracted from the 'prev_cursor' or 'next_cursor' property of a PaginatedResponseMetadata which is contained in the response of list and search API endpoints.. [optional]
                sort (str, none_type): The field to sort results by. A property name with a prepended '-' signifies descending order.. [optional]
                search_body (SearchBody): A request body containing a filter expression. This enables searching for items matching arbitrarily complex conditions. The list of attributes which can be used in filter expressions is available in the x-filterable vendor extension.  # Filter Expression Overview **Note: All keywords are case-insensitive**  ## Comparison Operators | Operator | Description | Example | | --- | --- | --- | | CONTAINS | Substring or membership testing for string and list attributes respectively. | field3 CONTAINS 'foobar', field4 CONTAINS TRUE  | | IN | Tests if field is a member of a list literal. List can contain a maximum of 100 values | field2 IN ['Goku', 'Vegeta'] | | GE | Tests if a field is greater than or equal to a literal value | field1 GE 1.2e-2 | | GT | Tests if a field is greater than a literal value | field1 GT 1.2e-2 | | LE | Tests if a field is less than or equal to a literal value | field1 LE 9000 | | LT | Tests if a field is less than a literal value | field1 LT 9.02 | | NE | Tests if a field is not equal to a literal value | field1 NE 42 | | EQ | Tests if a field is equal to a literal value | field1 EQ 42 |  ## Search Operator The SEARCH operator filters for items which have any filterable attribute that contains the input string as a substring, comparison is done case-insensitively. This is not restricted to attributes with string values. Specifically `SEARCH '12'` would match an item with an attribute with an integer value of `123`.  ## Logical Operators Ordered by precedence. | Operator | Description | Example | | --- | --- | --- | | NOT | Logical NOT (Right associative) | NOT field1 LE 9000 | | AND | Logical AND (Left Associative) | field1 GT 9000 AND field2 EQ 'Goku' | | OR | Logical OR (Left Associative) | field1 GT 9000 OR field2 EQ 'Goku' |  ## Grouping Parenthesis `()` can be used to override operator precedence.  For example: NOT (field1 LT 1234 AND field2 CONTAINS 'foo')  ## Literal Values | Literal      | Description | Examples | | --- | --- | --- | | Nil | Represents the absence of a value | nil, Nil, nIl, NIL | | Boolean | true/false boolean | true, false, True, False, TRUE, FALSE | | Number | Signed integer and floating point numbers. Also supports scientific notation. | 0, 1, -1, 1.2, 0.35, 1.2e-2, -1.2e+2 | | String | Single or double quoted | \"foo\", \"bar\", \"foo bar\", 'foo', 'bar', 'foo bar' | | Datetime | Formatted according to [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339) | 2018-04-27T18:39:26.397237+00:00 | | List | Comma-separated literals wrapped in square brackets | [0], [0, 1], ['foo', \"bar\"] |  ## Limitations - A maximum of 8 unique identifiers may be used inside a filter expression. . [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                SearchVDBGroupResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            return self.call_with_http_info(**kwargs)

        self.search_vdb_groups = _Endpoint(
            settings={
                'response_type': (SearchVDBGroupResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/vdb-groups/search',
                'operation_id': 'search_vdb_groups',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'limit',
                    'cursor',
                    'sort',
                    'search_body',
                ],
                'required': [],
                'nullable': [
                    'sort',
                ],
                'enum': [
                    'sort',
                ],
                'validation': [
                    'limit',
                    'cursor',
                ]
            },
            root_map={
                'validations': {
                    ('limit',): {

                        'inclusive_maximum': 1000,
                        'inclusive_minimum': 1,
                    },
                    ('cursor',): {
                        'max_length': 4096,
                        'min_length': 1,
                    },
                },
                'allowed_values': {
                    ('sort',): {
                        'None': None,
                        "ID": "id",
                        "-ID": "-id",
                        "NAME": "name",
                        "-NAME": "-name",
                        "LOCKED_BY": "locked_by",
                        "-LOCKED_BY": "-locked_by",
                        "LOCKED_BY_NAME": "locked_by_name",
                        "-LOCKED_BY_NAME": "-locked_by_name",
                        "DATABASE_TYPE": "database_type",
                        "-DATABASE_TYPE": "-database_type",
                        "STATUS": "status",
                        "-STATUS": "-status",
                        "LAST_SUCCESSFUL_REFRESH_TO_BOOKMARK_ID": "last_successful_refresh_to_bookmark_id",
                        "-LAST_SUCCESSFUL_REFRESH_TO_BOOKMARK_ID": "-last_successful_refresh_to_bookmark_id",
                        "LAST_SUCCESSFUL_REFRESH_TIME": "last_successful_refresh_time",
                        "-LAST_SUCCESSFUL_REFRESH_TIME": "-last_successful_refresh_time"
                    },
                },
                'openapi_types': {
                    'limit':
                        (int,),
                    'cursor':
                        (str,),
                    'sort':
                        (str, none_type,),
                    'search_body':
                        (SearchBody,),
                },
                'attribute_map': {
                    'limit': 'limit',
                    'cursor': 'cursor',
                    'sort': 'sort',
                },
                'location_map': {
                    'limit': 'query',
                    'cursor': 'query',
                    'sort': 'query',
                    'search_body': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__search_vdb_groups
        )

        def __start_vdb_group(
            self,
            vdb_group_id,
            **kwargs
        ):
            """Start a VDB Group.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.start_vdb_group(vdb_group_id, async_req=True)
            >>> result = thread.get()

            Args:
                vdb_group_id (str): The ID or name of the VDB Group.

            Keyword Args:
                start_vdb_group_parameters (StartVDBGroupParameters): The parameters to start a VDB Group.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                StartVDBGroupResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['vdb_group_id'] = \
                vdb_group_id
            return self.call_with_http_info(**kwargs)

        self.start_vdb_group = _Endpoint(
            settings={
                'response_type': (StartVDBGroupResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/vdb-groups/{vdbGroupId}/start',
                'operation_id': 'start_vdb_group',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'vdb_group_id',
                    'start_vdb_group_parameters',
                ],
                'required': [
                    'vdb_group_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'vdb_group_id',
                ]
            },
            root_map={
                'validations': {
                    ('vdb_group_id',): {
                        'max_length': 256,
                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'vdb_group_id':
                        (str,),
                    'start_vdb_group_parameters':
                        (StartVDBGroupParameters,),
                },
                'attribute_map': {
                    'vdb_group_id': 'vdbGroupId',
                },
                'location_map': {
                    'vdb_group_id': 'path',
                    'start_vdb_group_parameters': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__start_vdb_group
        )

        def __stop_vdb_group(
            self,
            vdb_group_id,
            **kwargs
        ):
            """Stop a VDB Group.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.stop_vdb_group(vdb_group_id, async_req=True)
            >>> result = thread.get()

            Args:
                vdb_group_id (str): The ID or name of the VDB Group.

            Keyword Args:
                stop_vdb_group_parameters (StopVDBGroupParameters): The parameters to stop a VDB Group.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                StopVDBGroupResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['vdb_group_id'] = \
                vdb_group_id
            return self.call_with_http_info(**kwargs)

        self.stop_vdb_group = _Endpoint(
            settings={
                'response_type': (StopVDBGroupResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/vdb-groups/{vdbGroupId}/stop',
                'operation_id': 'stop_vdb_group',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'vdb_group_id',
                    'stop_vdb_group_parameters',
                ],
                'required': [
                    'vdb_group_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'vdb_group_id',
                ]
            },
            root_map={
                'validations': {
                    ('vdb_group_id',): {
                        'max_length': 256,
                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'vdb_group_id':
                        (str,),
                    'stop_vdb_group_parameters':
                        (StopVDBGroupParameters,),
                },
                'attribute_map': {
                    'vdb_group_id': 'vdbGroupId',
                },
                'location_map': {
                    'vdb_group_id': 'path',
                    'stop_vdb_group_parameters': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__stop_vdb_group
        )

        def __unlock_vdb_group(
            self,
            vdb_group_id,
            **kwargs
        ):
            """Unlock a VDB Group.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.unlock_vdb_group(vdb_group_id, async_req=True)
            >>> result = thread.get()

            Args:
                vdb_group_id (str): The ID or name of the VDB Group.

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                VDBGroup
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['vdb_group_id'] = \
                vdb_group_id
            return self.call_with_http_info(**kwargs)

        self.unlock_vdb_group = _Endpoint(
            settings={
                'response_type': (VDBGroup,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/vdb-groups/{vdbGroupId}/unlock',
                'operation_id': 'unlock_vdb_group',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'vdb_group_id',
                ],
                'required': [
                    'vdb_group_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'vdb_group_id',
                ]
            },
            root_map={
                'validations': {
                    ('vdb_group_id',): {
                        'max_length': 256,
                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'vdb_group_id':
                        (str,),
                },
                'attribute_map': {
                    'vdb_group_id': 'vdbGroupId',
                },
                'location_map': {
                    'vdb_group_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__unlock_vdb_group
        )

        def __update_vdb_group_by_id(
            self,
            vdb_group_id,
            **kwargs
        ):
            """Update values of a VDB group.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.update_vdb_group_by_id(vdb_group_id, async_req=True)
            >>> result = thread.get()

            Args:
                vdb_group_id (str): The ID or name of the VDB Group.

            Keyword Args:
                update_vdb_group_parameters (UpdateVDBGroupParameters): The new data to update a VDB group.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                {str: (bool, date, datetime, dict, float, int, list, str, none_type)}
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['vdb_group_id'] = \
                vdb_group_id
            return self.call_with_http_info(**kwargs)

        self.update_vdb_group_by_id = _Endpoint(
            settings={
                'response_type': ({str: (bool, date, datetime, dict, float, int, list, str, none_type)},),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/vdb-groups/{vdbGroupId}',
                'operation_id': 'update_vdb_group_by_id',
                'http_method': 'PATCH',
                'servers': None,
            },
            params_map={
                'all': [
                    'vdb_group_id',
                    'update_vdb_group_parameters',
                ],
                'required': [
                    'vdb_group_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'vdb_group_id',
                ]
            },
            root_map={
                'validations': {
                    ('vdb_group_id',): {
                        'max_length': 256,
                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'vdb_group_id':
                        (str,),
                    'update_vdb_group_parameters':
                        (UpdateVDBGroupParameters,),
                },
                'attribute_map': {
                    'vdb_group_id': 'vdbGroupId',
                },
                'location_map': {
                    'vdb_group_id': 'path',
                    'update_vdb_group_parameters': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__update_vdb_group_by_id
        )
